import ExtractController from '../Controllers/ExtractController.js'
import BaseInfoController from '../Controllers/BaseInfoController.js'
import FilhosController from '../Controllers/FilhosController.js'
import LoginController from '../Controllers/LoginController.js'
import CardsController from '../Controllers/CardsController.js'
import FoodRestrictionController from '../Controllers/FoodRestrictionController.js'
import ValueRestrictionController from '../Controllers/ValueRestrictionController.js'
import ConsumerController from '../Controllers/ConsumerController.js'
import AutoRechargeController from '../Controllers/AutoRechargeController.js'
import MenuController from '../Controllers/MenuController.js'
import RegisterController from '../Controllers/RegisterController.js'
import EmailController from '../Controllers/EmailController.js'
import { log, logCommunication } from '../Controllers/LogController.js'
import { getRetailGeneralParams, getRetailSpecificParams } from '../Controllers/RetailParamsController.js'
import { getSubscriptionServices, addSubscriptionService, getSubscribedServicesByConsumer, hasAnySubscriptionService } from '../Controllers/SubscriptionServicesController.js'
import { getInvoices, doCardInvoicePayment } from '../Controllers/InvoiceController.js'

// Recharge
import CardRechargeController from '../Controllers/CardRechargeController.js'
import PixRechargeController from '../Controllers/PixRechargeController.js'
import RechargeController from '../Controllers/RechargeController.js'

import jwt from 'jsonwebtoken'

const uncrypt = function (token) {
    try {
        return jwt.verify(token, process.env.JWT_SECRET_KEY)
    } catch (e) {
        return  null
    }
}


const methods = {
    teste: async function ({ req, res, body }) {},
    getStoreBalance: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ExtractController.getStoreBalance({CDCONSUMIDOR: body.CDCONSUMIDOR, consDetails})
    },
    extrato: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ExtractController.getExtract({CDCONSUMIDOR: body.CDCONSUMIDOR, consDetails, DTINI: body.DTINI, DTFIM: body.DTFIM})
    },
    baseInfo: async function ({ req, res, body }) {
        return BaseInfoController.getBaseInfo()
    },
    getMenuVisibility: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return BaseInfoController.getMenuVisibility(consDetails)
    },
    getAllFiliais: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return BaseInfoController.getAllFiliais(consDetails)
    },
    getfilhos: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return FilhosController.getFilhos(consDetails)
    },
    getCards: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return CardsController.getCards(consDetails)
    },
    login: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return LoginController.login(req, body, consDetails)
    },
    getFoodRestriction: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return FoodRestrictionController.getFoodRestriction({CDCONSUMIDOR: body.CDCONSUMIDOR, consDetails})
    },
    updateFoodRestriction: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return FoodRestrictionController.updateFoodRestriction({CDCONSUMIDOR: body.CDCONSUMIDOR, QTCONSDIARAL: body.QTCONSDIARAL, IDPAI: body.IDPAI, CDPRODUTO: body.CDPRODUTO, cdWeekDays: body.cdWeekDays, consDetails})
    },
    getConsumerFamilies: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return FoodRestrictionController.getConsumerFamilies({ consDetails  })
    },
    getFamilyProducts : async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return FoodRestrictionController.getFamilyProducts({ CDCONSUMIDOR: body.CDCONSUMIDOR, CDFAMILISALD: body.CDFAMILISALD, consDetails  })
    },
    addFoodRestriction: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return FoodRestrictionController.addFoodRestriction({ CDCONSUMIDOR: body.CDCONSUMIDOR, productCodes: body.productCodes, CDFAMILISALD: body.CDFAMILISALD, QTCONSDIARAL: body.QTCONSDIARAL, cdWeekDays: body.cdWeekDays, consDetails  })
    },
    deleteFoodRestriction: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return FoodRestrictionController.deleteFoodRestriction({ CDCONSUMIDOR: body.CDCONSUMIDOR, CDFAMILISALD: body.CDFAMILISALD, CDPRODUTO: body.CDPRODUTO, consDetails  })
    },
    getCardStatus: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return CardsController.getCardStatus({ CDCONSUMIDOR: body.CDCONSUMIDOR, consDetails  })
    },
    toggleCardStatus: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return CardsController.toggleCardStatus({ IDSITCONSUMI: body.newStatus, CDCONSUMIDOR: body.CDCONSUMIDOR, consDetails  })
    },
    getValueRestrictions: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ValueRestrictionController.getValueRestrictions({ CDCONSUMIDOR: body.CDCONSUMIDOR, consDetails  })
    },
    updateValueRestriction: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ValueRestrictionController.updateValueRestriction({ CDCONSUMIDOR: body.CDCONSUMIDOR, CDFAMILISALD: body.CDFAMILISALD, VRCONSDIARAL: body.VRCONSDIARAL, consDetails  })
    },
    getUnrestrictedFamilies: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ValueRestrictionController.getUnrestrictedFamilies({ CDCONSUMIDOR: body.CDCONSUMIDOR, consDetails  })
    },
    addValueRestriction: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ValueRestrictionController.addValueRestriction({ CDCONSUMIDOR: body.CDCONSUMIDOR, CDFAMILISALD: body.CDFAMILISALD, VRCONSDIARAL: body.VRCONSDIARAL, consDetails  })
    },
    deleteValueRestriction: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ValueRestrictionController.deleteValueRestriction({ CDCONSUMIDOR: body.CDCONSUMIDOR, CDFAMILISALD: body.CDFAMILISALD, consDetails  })
    },
    getConsumerDetails: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ConsumerController.getConsumerDetails({ consDetails  })
    },
    updateProfile: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ConsumerController.updateProfile({ consDetails, body, req })
    },
    getAutoRechargeDetails: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return AutoRechargeController.getAutoRechargeDetails({ CDCONSUMIDOR: body.CDCONSUMIDOR , consDetails  })
    },
    confirmAutoRecharge: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        const result =  AutoRechargeController.confirmAutoRecharge({ CDCONSUMIDOR: body.CDCONSUMIDOR , minValue: body.minValue, rechargeValue: body.rechargeValue, CDFAMILISALD: body.CDFAMILISALD, consDetails  })
        return result
    },
    getMenuRestaurants: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return MenuController.getMenuRestaurants({ consDetails  })
    },
    getClients: async function ({ req, res, body }) {
        return RegisterController.getClients(req, res)
    },
    getStates: async function ({ req, res, body }) {
        return RegisterController.getStates(req, body)
    },
    getCities: async function ({ req, res, body }) {
        return RegisterController.getCities(req, body)
    },
    checkConsumerByLogin: async function ({ req, res, body }) {
        return RegisterController.checkConsumerByLogin(req, body)
    },
    checkConsumerByCPF: async function ({ req, res, body }) {
        return RegisterController.checkConsumerByCPF(req, body)
    },
    checkConsumerById: async function ({ req, res, body }) {
        return RegisterController.checkConsumerById(req, body)
    },
    registerUser: async function ({ req, res, body }) {
        return RegisterController.registerUser(req, body)
    },
    getRestaurantGroups: async function ({ req, res, body }) {
        return MenuController.getRestaurantGroups({ CDFILIAL: body.CDFILIAL, CDLOJA: body.CDLOJA, NRCONFTELA: body.NRCONFTELA })
    },
    buildMenu: async function ({ req, res, body }) {
        const menu = await MenuController.buildMenu({
            CDCLIENTE: body.CDCLIENTE,
            CDFILIAL: body.CDFILIAL,
            CDCAIXA: body.CDCAIXA,
            CDLOJA: body.CDLOJA,
            NRCONFTELA: body.NRCONFTELA,
            groups: body.groups,
        })
        return menu
    },
    getCardRechargeDetails: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return CardRechargeController.getCardRechargeDetails({ consDetails  })
    },
    changePassword: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ConsumerController.changePassword({ consDetails, currentPassword: body.currentPassword, newPassword: body.newPassword })
    },
    sendEmail: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return EmailController.sendEmail({ DSEMAILCONS: body.email, subject: body.subject, schoolAdminEmail: body.schoolAdminEmail, htmlFunction: body.htmlFunction, functionParams: body.functionParams, consDetails})
    },
    getClients: async function ({ req, res, body }) {
        return LoginController.getClients()
    },
    forgotPassword: async function ({ req, res, body }) {
        return LoginController.forgotPassword(body)
    },
    updatePasswordAfterRecover: async function ({ req, res, body }) {
        return LoginController.updatePasswordAfterRecover(body)
    },
    getFullBalance: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return ExtractController.getFullBalance({ consDetails })
    },
    registerCreditCard: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return CardsController.registerCreditCard(body, consDetails)
    },
    deleteCreditCard: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return CardsController.deleteCreditCard(body)
    },
    log: function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return log({ ...body, consDetails, serverSide: false })
    },
    logCommunication: function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return logCommunication({ ...body, consDetails, serverSide: false })
    },
    doCardRecharge: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return CardRechargeController.doCardRecharge({ ...body, consDetails })
    },
    doCardInvoicePayment: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return doCardInvoicePayment({ ...body, consDetails })
    },
    getQrcodePix: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return PixRechargeController.getQrcode({ totalValue: body.totalValue, isInvoiceMode:body.isInvoiceMode, consDetails, idBoletos: body.idBoletos })
    },
    checkPixPayment: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return PixRechargeController.checkPixPayment({ NRTRANSACAO: body.NRTRANSACAO, nit: body.nit, pixTimeout: body.pixTimeout, totalValue: body.totalValue, rechargeValues: body.rechargeValues, consDetails })
    },
    checkPixInvoicePayment: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return PixRechargeController.checkPixInvoicePayment({ idBoletos: body.idBoletos, nit: body.nit, pixTimeout: body.pixTimeout, consDetails, totalValue: body.totalValue })
    },
    checkOpenedPayment: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return PixRechargeController.checkOpenedPayment({ consDetails })
    },
    getRetailGeneralParams: async function () {
        return getRetailGeneralParams()
    },
    getRetailSpecificParams: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return getRetailSpecificParams(consDetails.CDCLIENTE, consDetails.CDFILIAL)
    },
    saveTempRecharge: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return PixRechargeController.saveTempRecharge({ ...body, consDetails })
    },
    checkSonsBalances: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        await RechargeController.checkSonsBalances({ consDetails })
        return FilhosController.getFilhos(consDetails)
    },
    getSubscriptionServices: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return getSubscriptionServices({ CDFILIAL: consDetails.CDFILIAL })
    },
    addSubscriptionService: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return addSubscriptionService(body, consDetails)
    },
    getInvoices: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return getInvoices({ NRCPFRESPCON: consDetails.NRCPFRESPCON, CDCONSUMIDOR: body.CDCONSUMIDOR })
    },
    getSubscribedServicesByConsumer: async function ({ req, res, body }) {
        const consDetails = uncrypt(req.headers.authorization)
        return getSubscribedServicesByConsumer(consDetails, body) 
    },
    hasAnySubscriptionService: async function ({req, res, body}) {
        const consDetails = uncrypt(req.headers.authorization)
        return hasAnySubscriptionService({ CDFILIAL: consDetails.CDFILIAL })
    }
}

export { methods }
